# crystalpy
Perfect crystal python tools.

Contains code to calculate diffraction for perfect crystals using dynamical diffraction theory. It uses the Zachariasen formalism. It contain tools to simulate polarization of crystals by Mueller/Stokes optics.

Project still under development, but usable. 

The Ms Thesis related to this project is https://github.com/oasys-kit/crystalpy/blob/master/doc/tesi-finale.pdf

A graphical interface is available under Oasys:  https://github.com/oasys-kit/OASYS-CRYSTALPY
